using System;
using NeonScripting;
using System.Collections;
using System.IO;
using System.Text;
using System.Linq;

namespace Neon
{
	public class Script
	{
		public bool Run(INeonScriptHost host)
		{
			int total = host.Tracks.Count();
			int idx = 0;
			bool recalcValues = host.RemoteCalls.ConfirmationDialog("Re-calculate existing values?");
			foreach(var track in host.Tracks) 
			{
				bool changes = false;
				string listbpm = "";
				if (track.Bpm == 0)
				{
					listbpm = "";
				} else {
					listbpm = track.Bpm.ToString();
				}
				host.UpdateProgress(string.Format("\nTrack {0}/{1}\n\nAcoustID\t: {2}\nbpm\t: {3}\nKey\t: {4}", idx++, total, track.AcoustId, listbpm, track.InitialKey));
				if (track.AcoustId == string.Empty || track.AcoustId.Length == null || recalcValues)
				{
					host.UpdateProgress(string.Format("\nTrack {0}/{1}\n\nAcoustID\t: calculating...\nbpm\t: {2}\nKey\t: {3}", idx, total, listbpm, track.InitialKey));
					var aid = host.RemoteCalls.CalculateAcoustId(track.FullFilename);
					track.AcoustId = aid;
					changes = true;
				}
				if (track.Bpm == 0 || recalcValues)
				{
					host.UpdateProgress(string.Format("\nTrack {0}/{1}\n\nAcoustID\t: {2}\nbpm\t: calculating...\nKey\t: {3}", idx, total, track.AcoustId, track.InitialKey));
					var bpm = host.RemoteCalls.CalculateBpm(track.FullFilename);
					track.Bpm = bpm;
					if (track.Bpm == 0)
					{
						listbpm = "";
					} else {
						listbpm = track.Bpm.ToString();
					}
					changes = true;
				}
				if (track.InitialKey == "" || track.InitialKey == string.Empty || recalcValues)
				{
					host.UpdateProgress(string.Format("\nTrack {0}/{1}\n\nAcoustID\t: {2}\nbpm\t: {3}\nKey\t: calculating...", idx, total, track.AcoustId, listbpm));
					var key = host.RemoteCalls.CalculateMusicKey(track.FullFilename);
					track.InitialKey = key;
					changes = true;
				}
				host.UpdateProgress(string.Format("\nTrack {0}/{1}\n\nAcoustID\t: {2}\nbpm\t: {3}\nKey\t: {4}", idx, total, track.AcoustId, listbpm, track.InitialKey));
				if (!changes)
				{
					track.IgnoreChanges = true;
				}
			}
			host.RemoteCalls.CommitAllChanges(host.Tracks);
			return true;
		}
	}
}